#start_mode ( mode where the test begins )
2

##########################################################################
# SPECIAL NOTE:
#   Most procedures specify a response to "emergency" and 
#   "abort_limit" events and always use the same procedures. 
#   If this is the case, these specifications should be removed 
#   from the procedure files and place in the header file as 
#   @UNIVERSAL_EVENTS and @UNIVERSAL_REGISTERED_EVENTS.  Then 
#   these responses will be in effect for all test procedures 
#
#  @GLOBAL_EVENTS and @REGISTERED_EVENTS specify events that are handled
#  the same regardless of which test mode is active.
#
#  If neither the  next_mode  or the  test_procedure  are specified, then
#  the mode is just terminated and the normal path is taken.
#
#  If the  next_mode  is specified, but the  test_procedure  is not,
#  then the test will jump to that mode in this procedure.  
#
#  If the  test_procedure  is specified, but the  next_mode  is not,
#  then the test will jump to that sub-procedure.  If the sub-procedure
#  exits via a RETURN, the the current procedure will begin executing
#  at the  default_next_mode  specified for the test mode that was
#  interrupted.
#
#  If both  next_mode  and  test_procedure  are specified, the next_mode
#  will be ignored.  The return will be to the default_next_mode
#  of the test mode that was interrupted by the event.  If the 
#   test_procedure  file does not exist or cannot be opened, then this
#  mode will be executed next.

@GLOBAL_EVENTS
#event_name              next_mode            test_procedure
emergency                90                   /specs/gp/gp_emergency
abort_limit              90                   /specs/gp/gp_shutdown


@REGISTERED_EVENTS
#event_name              next_mode            test_procedure
stop_test                90                   /specs/gp/gp_shutdown
idle_mode                90                   -


##############################################################################

##############################################################################

@MODE
  #mode_number       timeout                   next_mode
  2                  10.0[sec]                 5
  #mode_description (60 characters max)
Initialize vrbl file parameters

@PARAMETERS
  #start_type     label            value
  AT_START       count             0[none]                                 
  AT_START       loop1             9[none]                                 


##############################################################################

@MODE
  #mode_number       timeout                   next_mode
  5                  12[sec]                   10
  #mode_description (60 characters max)
Set Engine to Development Mode

@BACKGROUND_TASK
  #list of background tasks or scripts
  #type_code        "command"                            kill_option
  AT_START           "dev                             "    NONE


##############################################################################

@MODE
  #mode_number       timeout                   next_mode
  10                  15.0[sec]                 15
  #mode_description (60 characters max)
* Initiate low-speed loger process  *

@BACKGROUND_TASK
  #list of background tasks or scripts
  #type_code        "command"                            kill_option
  AT_START           "/asset/bin/floger /specs/logr_spec.prm1"    NONE


##############################################################################

@MODE
  #mode_number       timeout                   next_mode
  15                  15.0[sec]                 20
  #mode_description (60 characters max)
* Start logging data... *

@SET_EVENTS
  #list of event_names
  #start_type      event_name
  AT_START        start_log_prm   


##############################################################################

@MODE
  #mode_number       timeout                   next_mode
  20                  30[sec]                   23
  #mode_description (60 characters max)
All regens are turned off using shortcuts 

@BACKGROUND_TASK
  #list of background tasks or scripts
  #type_code        "command"                            kill_option
  AT_START           "/specs/cmds/kdst_stop           "    NONE
  AT_START           "/specs/cmds/kdsx_stop           "    NONE
  AT_START           "/specs/cmds/kdnx_stop           "    NONE
  AT_START           "/specs/cmds/fcc                 "    NONE
  AT_START           "/specs/cmds/rs                  "    NONE


##############################################################################

@MODE
  #mode_number       timeout                   next_mode
  23                  10.0[sec]                 25
  #mode_description (60 characters max)
Initialize vrbl file parameters

@PARAMETERS
  #start_type     label            value
  AT_START       count             "count + 1[none]"                       


##############################################################################

@MODE
  #mode_number       timeout                   next_mode
  25                  10[sec]                   30
  #mode_description (60 characters max)
Read Setpoints

@AUXILIARY_TASK
  #start_type              stop_path         failure_path
  AT_START                 MODE_TERMINATE           ELSE_MODE               

  #task pathname           spec file pathname
  /asset/bin/vrbl_to_file  "/specs/gp/vrbl_o2sensor_new READ count"


##############################################################################

@MODE
  #mode_number       timeout                   next_mode
  30                  5[sec]                    33
  #mode_description (60 characters max)
Check point to see if last ...

@IF_TRUE
  "speed_setpt >= idle_spd"

@ELSE_MODE
  #alternate mode or procedure to be executed when conditional tests fail
  87


##############################################################################

@MODE
  #mode_number       timeout                   next_mode
  33                  5[sec]                    35
  #mode_description (60 characters max)
Loop count check...

@IF_TRUE
  "loop1 <= 10[none]"

@ELSE_MODE
  #alternate mode or procedure to be executed when conditional tests fail
  23


##############################################################################

@MODE
  #mode_number       timeout                   next_mode
  35                  5[min]                    40
  #mode_description (60 characters max)
* 3 min stability *

@DYNO
  #OPEN/CLOSED_LOOP
  CLOSED_LOOP

@THROTTLE
  #OPEN/CLOSED_LOOP
  CLOSED_LOOP

@SPEED
  #start_target(%)      [end_target(%)]       [ramp_rate[%)]
  RPM                   speed_setpt           10[rpm]             

@TORQUE
  #start_target(%)      [end_target(%)]       [ramp_rate[%)]
  ana_torq              torque_setpt          5[lb_ft]            


##############################################################################

@MODE
  #mode_number       timeout                   next_mode
  40                  15.00[sec]                45
  #mode_description (60 characters max)
* ...wait 15 sec *


##############################################################################

@MODE
  #mode_number       timeout                   next_mode
  45                  5[min]                    50
  #mode_description (60 characters max)
Set torque to high value for passive DeSoot 

@DYNO
  #OPEN/CLOSED_LOOP
  CLOSED_LOOP

@THROTTLE
  #OPEN/CLOSED_LOOP
  CLOSED_LOOP

@SPEED
  #start_target(%)      [end_target(%)]       [ramp_rate[%)]
  RPM                   speed_setpt           10[rpm]             

@TORQUE
  #start_target(%)      [end_target(%)]       [ramp_rate[%)]
  ana_torq              550[lb_ft]            10[lb_ft]           


##############################################################################

@MODE
  #mode_number       timeout                   next_mode
  50                  15[min]                   55
  #mode_description (60 characters max)
* Run for 15 min of DeSoot - Passive *

@DYNO
  #OPEN/CLOSED_LOOP
  CLOSED_LOOP

@THROTTLE
  #OPEN/CLOSED_LOOP
  CLOSED_LOOP

@SPEED
  #start_target(%)      [end_target(%)]       [ramp_rate[%)]
  RPM                   1500[rpm]             10[rpm]             

@TORQUE
  #start_target(%)      [end_target(%)]       [ramp_rate[%)]
  ana_torq              550[lb_ft]            5[lb_ft]            


##############################################################################

@MODE
  #mode_number       timeout                   next_mode
  55                  5[min]                    60
  #mode_description (60 characters max)
* Run at 1500-150 - Disable Passive DeSoot *

@DYNO
  #OPEN/CLOSED_LOOP
  CLOSED_LOOP

@THROTTLE
  #OPEN/CLOSED_LOOP
  CLOSED_LOOP

@SPEED
  #start_target(%)      [end_target(%)]       [ramp_rate[%)]
  RPM                   1500[rpm]             10[rpm]             

@TORQUE
  #start_target(%)      [end_target(%)]       [ramp_rate[%)]
  ana_torq              150[lb_ft]            5[lb_ft]            


##############################################################################

@MODE
  #mode_number       timeout                   next_mode
  60                  0.0[min]                  70
  #mode_description (60 characters max)
Enable DeSOx

@PROCEDURE
  #pathname;mode
  '/specs/gp/gp_bbird_dsxon_k1.0'



##############################################################################

@MODE
  #mode_number       timeout                   next_mode
  70                  5[min]                    75
  #mode_description (60 characters max)
Disable DeSOx - lean operation for 5 min


##############################################################################

@MODE
  #mode_number       timeout                   next_mode
  75                  2[sec]                    33
  #mode_description (60 characters max)
Increment count and repeat

@PARAMETERS
  #start_type     label            value
  AT_END         loop1             "loop1 + 1[none]"                       


##############################################################################

@MODE
  #mode_number       timeout                   next_mode
  87                  5[min]                    88
  #mode_description (60 characters max)
End of points

@DYNO
  #OPEN/CLOSED_LOOP
  CLOSED_LOOP

@THROTTLE
  #OPEN/CLOSED_LOOP
  CLOSED_LOOP

@SPEED
  #start_target(%)      [end_target(%)]       [ramp_rate[%)]
  RPM                   1500[RPM]             10[RPM]             

@TORQUE
  #start_target(%)      [end_target(%)]       [ramp_rate[%)]
  ana_torq              150[lb_ft]            5[lb_ft]            


##############################################################################

@MODE
  #mode_number       timeout                   next_mode
  88                  90[sec]                   89
  #mode_description (60 characters max)
Still cool mode : stop logers 

@SET_EVENTS
  #list of event_names
  #start_type      event_name
  AT_START        stop_log_prm    


##############################################################################

@MODE
  #mode_number       timeout                   next_mode
  89                  15[sec]                   90
  #mode_description (60 characters max)
Still cool mode : slay logers  

@BACKGROUND_TASK
  #list of background tasks or scripts
  #type_code        "command"                            kill_option
  AT_START           "/bin/slay -f floger             "    NONE


##############################################################################

@MODE
  #mode_number       timeout                   next_mode
  90                  1.00[min]                 93
  #mode_description (60 characters max)
May be ATA cmd prob., fast idle 1 min, shut down next 

@ENGINE_CONTROL_MODE
  4[none]


@DYNO
  #OPEN/CLOSED_LOOP
  CLOSED_LOOP

@THROTTLE
  #OPEN/CLOSED_LOOP
  CLOSED_LOOP

@SPEED
  #start_target(%)      [end_target(%)]       [ramp_rate[%)]
  RPM                   1500.00[RPM]          10[RPM]             

@TORQUE
  #start_target(%)      [end_target(%)]       [ramp_rate[%)]
  ana_torq              50.00[LB_FT]          5[lb_ft]            


##############################################################################

@MODE
  #mode_number       timeout                   next_mode
  93                  1.0[sec]                  95
  #mode_description (60 characters max)
Turn off cart and slay floger: shutdown_cat is next


##############################################################################

@MODE
  #mode_number       timeout                   next_mode
  95                  0.0[min]                  95
  #mode_description (60 characters max)
Shutdown mode Engine will idle 5 minutes and shutdown.

@PROCEDURE
  #pathname;mode
  '/specs/gp/gp_shutdown'

